@@ -2,14 +2,15 @@
 build_time_vars = {'ABIFLAGS': 'm',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
+ 'ANDROID_API_LEVEL': 0,
  'AR': 'powerpc64le-conda_cos7-linux-gnu-ar',
  'ARFLAGS': 'rc',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '-IObjects -IInclude -IPython',
  'BASEMODLIBS': '',
  'BINDIR': '/opt/anaconda1anaconda2anaconda3/bin',
- 'BINLIBDEST': '/opt/anaconda1anaconda2anaconda3/lib/python3.5',
- 'BLDLIBRARY': 'libpython3.5m.a',
+ 'BINLIBDEST': '/opt/anaconda1anaconda2anaconda3/lib/python3.6',
+ 'BLDLIBRARY': 'libpython3.6m.a',
  'BLDSHARED': 'powerpc64le-conda_cos7-linux-gnu-gcc -pthread -shared -Wl,-O2 '
               '-Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now '
               '-Wl,-rpath,/opt/anaconda1anaconda2anaconda3/lib '
@@ -17,29 +18,43 @@ build_time_vars = {'ABIFLAGS': 'm',
               '-Wl,-O2 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
               '-Wl,-z,now '
               '-Wl,-rpath,/opt/anaconda1anaconda2anaconda3/lib '
-              '-L/opt/anaconda1anaconda2anaconda3/lib',
+              '-L/opt/anaconda1anaconda2anaconda3/lib '
+              '   '
+              '',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'powerpc64le-conda_cos7-linux-gnu',
  'BYTESTR_DEPS': '\\',
  'CC': 'powerpc64le-conda_cos7-linux-gnu-gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -fwrapv -O3 -Wall '
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -fwrapv -O2 -Wall '
            '-Wstrict-prototypes -mcpu=power8 -mtune=power8 -mpower8-fusion '
            '-mpower8-vector -ftree-vectorize -fPIC -fstack-protector-strong '
-           '-fno-plt -O3 -pipe -mcpu=power8 -mtune=power8 -mpower8-fusion '
-           '-mpower8-vector -ftree-vectorize -fPIC -fstack-protector-strong '
-           '-fno-plt -O3 -pipe',
+           '-fno-plt -O2 '
+           '-fdebug-prefix-map=/opt/conda/conda-bld/python_1512347718438/work=/usr/local/src/conda/python-3.6.3 '
+           '-fdebug-prefix-map=/opt/anaconda1anaconda2anaconda3=/usr/local/src/conda-prefix '
+           '-pipe     '
+           ' -mcpu=power8 -mtune=power8 -mpower8-fusion -mpower8-vector '
+           '-ftree-vectorize -fPIC -fstack-protector-strong -fno-plt -O2 '
+           '-fdebug-prefix-map=/opt/conda/conda-bld/python_1512347718438/work=/usr/local/src/conda/python-3.6.3 '
+           '-fdebug-prefix-map=/opt/anaconda1anaconda2anaconda3=/usr/local/src/conda-prefix '
+           '-pipe     '
+           '',
  'CFLAGSFORSHARED': '',
  'CFLAGS_ALIASING': '',
- 'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-mcpu=power8 -mtune=power8 -mpower8-fusion '
                      '-mpower8-vector -ftree-vectorize -fPIC '
-                     '-fstack-protector-strong -fno-plt -O3 -pipe',
- 'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
- 'CONFIGURE_CPPFLAGS': '-D_FORTIFY_SOURCE=2 -O3 '
+                     '-fstack-protector-strong -fno-plt -O2 '
+                     '-fdebug-prefix-map=/opt/conda/conda-bld/python_1512347718438/work=/usr/local/src/conda/python-3.6.3 '
+                     '-fdebug-prefix-map=/opt/anaconda1anaconda2anaconda3=/usr/local/src/conda-prefix '
+                     '-pipe    '
+                     ' ',
+ 'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
+                            '-Wno-unused-parameter '
+                            '-Wno-missing-field-initializers',
+ 'CONFIGURE_CPPFLAGS': '-D_FORTIFY_SOURCE=2 -O2 '
                        '-I/opt/anaconda1anaconda2anaconda3/include',
  'CONFIGURE_LDFLAGS': '-Wl,-O2 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
                       '-Wl,-z,now '
@@ -52,42 +67,47 @@ build_time_vars = {'ABIFLAGS': 'm',
                 "'--with-system-ffi' '--enable-loadable-sqlite-extensions' "
                 "'--with-tcltk-includes=-I/opt/anaconda1anaconda2anaconda3/include' "
                 "'--with-tcltk-libs=-L/opt/anaconda1anaconda2anaconda3/lib "
-                "-ltcl8.6 -ltk8.6' '--disable-shared' "
+                "-ltcl8.6 -ltk8.6' '--enable-optimizations' '--with-lto' "
+                "'--disable-shared' "
                 "'build_alias=powerpc64le-conda_cos7-linux-gnu' "
                 "'host_alias=powerpc64le-conda_cos7-linux-gnu' "
                 "'CC=powerpc64le-conda_cos7-linux-gnu-gcc' "
                 "'CFLAGS=-mcpu=power8 -mtune=power8 -mpower8-fusion "
                 '-mpower8-vector -ftree-vectorize -fPIC '
-                "-fstack-protector-strong -fno-plt -O3 -pipe ' "
-                "'LDFLAGS=-Wl,-O2 -Wl,--sort-common -Wl,--as-needed "
-                '-Wl,-z,relro -Wl,-z,now '
+                '-fstack-protector-strong -fno-plt -O2 '
+                '-fdebug-prefix-map=/opt/conda/conda-bld/python_1512347718438/work=/usr/local/src/conda/python-3.6.3 '
+                '-fdebug-prefix-map=/opt/anaconda1anaconda2anaconda3=/usr/local/src/conda-prefix '
+                '-pipe    '
+                " ' 'LDFLAGS=-Wl,-O2 "
+                '-Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now '
                 '-Wl,-rpath,/opt/anaconda1anaconda2anaconda3/lib '
                 "-L/opt/anaconda1anaconda2anaconda3/lib' "
-                "'CPPFLAGS=-D_FORTIFY_SOURCE=2 -O3 "
+                "'CPPFLAGS=-D_FORTIFY_SOURCE=2 -O2 "
                 "-I/opt/anaconda1anaconda2anaconda3/include' "
                 "'CPP=/opt/anaconda1anaconda2anaconda3/bin/powerpc64le-conda_cos7-linux-gnu-cpp' "
                 "'PKG_CONFIG_PATH=/opt/anaconda1anaconda2anaconda3/lib/pkgconfig'",
  'CONFINCLUDEDIR': '/opt/anaconda1anaconda2anaconda3/include',
- 'CONFINCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python3.5m',
- 'COREPYTHONPATH': ':plat-linux',
- 'COVERAGE_INFO': '/opt/conda/conda-bld/python_1512342458352/work/build-static/coverage.info',
- 'COVERAGE_REPORT': '/opt/conda/conda-bld/python_1512342458352/work/build-static/lcov-report',
+ 'CONFINCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python3.6m',
+ 'COREPYTHONPATH': ':',
+ 'COVERAGE_INFO': '/opt/conda/conda-bld/python_1512347718438/work/build-static/coverage.info',
+ 'COVERAGE_REPORT': '/opt/conda/conda-bld/python_1512347718438/work/build-static/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/opt/conda/conda-bld/python_1512342458352/work/Include '
-             '-D_FORTIFY_SOURCE=2 -O3 '
+             '-I/opt/conda/conda-bld/python_1512347718438/work/Include '
+             '-D_FORTIFY_SOURCE=2 -O2 '
              '-I/opt/anaconda1anaconda2anaconda3/include '
-             '-D_FORTIFY_SOURCE=2 -O3 '
+             '-D_FORTIFY_SOURCE=2 -O2 '
              '-I/opt/anaconda1anaconda2anaconda3/include',
  'CXX': 'powerpc64le-conda_cos7-linux-gnu-c++ -pthread',
  'DESTDIRS': '/opt/anaconda1anaconda2anaconda3 '
              '/opt/anaconda1anaconda2anaconda3/lib '
-             '/opt/anaconda1anaconda2anaconda3/lib/python3.5 '
-             '/opt/anaconda1anaconda2anaconda3/lib/python3.5/lib-dynload',
- 'DESTLIB': '/opt/anaconda1anaconda2anaconda3/lib/python3.5',
+             '/opt/anaconda1anaconda2anaconda3/lib/python3.6 '
+             '/opt/anaconda1anaconda2anaconda3/lib/python3.6/lib-dynload',
+ 'DESTLIB': '/opt/anaconda1anaconda2anaconda3/lib/python3.6',
  'DESTPATH': '',
- 'DESTSHARED': '/opt/anaconda1anaconda2anaconda3/lib/python3.5/lib-dynload',
+ 'DESTSHARED': '/opt/anaconda1anaconda2anaconda3/lib/python3.6/lib-dynload',
+ 'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
          'Makefile.pre.in Include Lib Misc Ext-dummy',
@@ -99,6 +119,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
+ 'DTRACE': '',
+ 'DTRACE_DEPS': '\\',
+ 'DTRACE_HEADERS': '',
+ 'DTRACE_OBJS': '',
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
  'ENSUREPIP': 'no',
@@ -106,7 +130,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'EXEMODE': 755,
  'EXTRAMACHDEPPATH': '',
  'EXTRATESTOPTS': '',
- 'EXT_SUFFIX': '.cpython-35m-powerpc64le-linux-gnu.so',
+ 'EXT_SUFFIX': '.cpython-36m-powerpc64le-linux-gnu.so',
  'FILEMODE': 644,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
@@ -137,13 +161,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_BROKEN_SEM_GETVALUE': 0,
  'HAVE_BROKEN_UNSETENV': 0,
  'HAVE_BUILTIN_ATOMIC': 1,
- 'HAVE_C99_BOOL': 1,
  'HAVE_CHFLAGS': 0,
  'HAVE_CHOWN': 1,
  'HAVE_CHROOT': 1,
  'HAVE_CLOCK': 1,
  'HAVE_CLOCK_GETRES': 1,
  'HAVE_CLOCK_GETTIME': 1,
+ 'HAVE_CLOCK_SETTIME': 1,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
@@ -157,6 +181,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DECL_ISFINITE': 1,
  'HAVE_DECL_ISINF': 1,
  'HAVE_DECL_ISNAN': 1,
+ 'HAVE_DECL_RTLD_DEEPBIND': 1,
+ 'HAVE_DECL_RTLD_GLOBAL': 1,
+ 'HAVE_DECL_RTLD_LAZY': 1,
+ 'HAVE_DECL_RTLD_LOCAL': 1,
+ 'HAVE_DECL_RTLD_NODELETE': 1,
+ 'HAVE_DECL_RTLD_NOLOAD': 1,
+ 'HAVE_DECL_RTLD_NOW': 1,
  'HAVE_DECL_TZNAME': 0,
  'HAVE_DEVICE_MACROS': 1,
  'HAVE_DEV_PTC': 0,
@@ -251,8 +282,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_INET_ATON': 1,
  'HAVE_INET_PTON': 1,
  'HAVE_INITGROUPS': 1,
- 'HAVE_INT32_T': 1,
- 'HAVE_INT64_T': 1,
  'HAVE_INTTYPES_H': 1,
  'HAVE_IO_H': 0,
  'HAVE_IPA_PURE_CONST_BUG': 0,
@@ -286,7 +315,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
  'HAVE_LONG_DOUBLE': 1,
- 'HAVE_LONG_LONG': 1,
  'HAVE_LSTAT': 1,
  'HAVE_LUTIMES': 1,
  'HAVE_MAKEDEV': 1,
@@ -309,7 +337,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_NICE': 1,
  'HAVE_OPENAT': 1,
  'HAVE_OPENPTY': 1,
- 'HAVE_OSX105_SDK': 0,
  'HAVE_PATHCONF': 1,
  'HAVE_PAUSE': 1,
  'HAVE_PIPE2': 1,
@@ -386,6 +413,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SIGWAIT': 1,
  'HAVE_SIGWAITINFO': 1,
  'HAVE_SNPRINTF': 1,
+ 'HAVE_SOCKADDR_ALG': 1,
  'HAVE_SOCKADDR_SA_LEN': 0,
  'HAVE_SOCKADDR_STORAGE': 1,
  'HAVE_SOCKETPAIR': 1,
@@ -404,6 +432,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_STRING_H': 1,
  'HAVE_STRLCPY': 0,
  'HAVE_STROPTS_H': 0,
+ 'HAVE_STRUCT_PASSWD_PW_GECOS': 1,
+ 'HAVE_STRUCT_PASSWD_PW_PASSWD': 1,
  'HAVE_STRUCT_STAT_ST_BIRTHTIME': 0,
  'HAVE_STRUCT_STAT_ST_BLKSIZE': 1,
  'HAVE_STRUCT_STAT_ST_BLOCKS': 1,
@@ -441,6 +471,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SYS_STATVFS_H': 1,
  'HAVE_SYS_STAT_H': 1,
  'HAVE_SYS_SYSCALL_H': 1,
+ 'HAVE_SYS_SYSMACROS_H': 1,
  'HAVE_SYS_SYS_DOMAIN_H': 0,
  'HAVE_SYS_TERMIO_H': 0,
  'HAVE_SYS_TIMES_H': 1,
@@ -466,9 +497,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_TRUNCATE': 1,
  'HAVE_TZNAME': 0,
  'HAVE_UCS4_TCL': 0,
- 'HAVE_UINT32_T': 1,
- 'HAVE_UINT64_T': 1,
- 'HAVE_UINTPTR_T': 1,
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
@@ -494,16 +522,16 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HOST_GNU_TYPE': 'powerpc64le-conda_cos7-linux-gnu',
  'INCLDIRSTOMAKE': '/opt/anaconda1anaconda2anaconda3/include '
                    '/opt/anaconda1anaconda2anaconda3/include '
-                   '/opt/anaconda1anaconda2anaconda3/include/python3.5m '
-                   '/opt/anaconda1anaconda2anaconda3/include/python3.5m',
+                   '/opt/anaconda1anaconda2anaconda3/include/python3.6m '
+                   '/opt/anaconda1anaconda2anaconda3/include/python3.6m',
  'INCLUDEDIR': '/opt/anaconda1anaconda2anaconda3/include',
- 'INCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python3.5m',
+ 'INCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python3.6m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'libpython3.5m.a',
+ 'INSTSONAME': 'libpython3.6m.a',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'powerpc64le-conda_cos7-linux-gnu-c++ -pthread -shared',
@@ -512,9 +540,10 @@ build_time_vars = {'ABIFLAGS': 'm',
             '-L/opt/anaconda1anaconda2anaconda3/lib '
             '-Wl,-O2 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now '
             '-Wl,-rpath,/opt/anaconda1anaconda2anaconda3/lib '
-            '-L/opt/anaconda1anaconda2anaconda3/lib',
+            '-L/opt/anaconda1anaconda2anaconda3/lib '
+            '   ',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython3.5m.a',
+ 'LDLIBRARY': 'libpython3.6m.a',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'powerpc64le-conda_cos7-linux-gnu-gcc -pthread -shared -Wl,-O2 '
              '-Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now '
@@ -523,18 +552,19 @@ build_time_vars = {'ABIFLAGS': 'm',
              '-Wl,-O2 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
              '-Wl,-z,now '
              '-Wl,-rpath,/opt/anaconda1anaconda2anaconda3/lib '
-             '-L/opt/anaconda1anaconda2anaconda3/lib',
- 'LDVERSION': '3.5m',
+             '-L/opt/anaconda1anaconda2anaconda3/lib '
+             '   ',
+ 'LDVERSION': '3.6m',
  'LIBC': '',
- 'LIBDEST': '/opt/anaconda1anaconda2anaconda3/lib/python3.5',
+ 'LIBDEST': '/opt/anaconda1anaconda2anaconda3/lib/python3.6',
  'LIBDIR': '/opt/anaconda1anaconda2anaconda3/lib',
  'LIBFFI_INCLUDEDIR': '/opt/anaconda1anaconda2anaconda3/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/opt/anaconda1anaconda2anaconda3/lib/pkgconfig',
- 'LIBPL': '/opt/anaconda1anaconda2anaconda3/lib/python3.5/config-3.5m',
- 'LIBRARY': 'libpython3.5m.a',
+ 'LIBPL': '/opt/anaconda1anaconda2anaconda3/lib/python3.6/config-3.6m-powerpc64le-linux-gnu',
+ 'LIBRARY': 'libpython3.6m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lpthread -ldl  -lutil',
@@ -549,39 +579,40 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LOCALMODLIBS': '',
  'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'linux',
- 'MACHDEPPATH': ':plat-linux',
- 'MACHDEPS': 'plat-linux',
+ 'MACHDEPPATH': ':',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/opt/anaconda1anaconda2anaconda3/lib/python3.5',
+ 'MACHDESTLIB': '/opt/anaconda1anaconda2anaconda3/lib/python3.6',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'powerpc64le-conda_cos7-linux-gnu-gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/opt/conda/conda-bld/python_1512342458352/work/Modules/makesetup',
+ 'MAKESETUP': '/opt/conda/conda-bld/python_1512347718438/work/Modules/makesetup',
  'MANDIR': '/opt/anaconda1anaconda2anaconda3/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODLIBS': '',
- 'MODNAMES': '_thread _signal posix errno pwd _sre _codecs _weakref _functools '
-             '_operator _collections itertools atexit _stat time _locale _io '
-             'zipimport faulthandler _tracemalloc _symtable xxsubtype',
- 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  '
-            'Modules/posixmodule.o  Modules/errnomodule.o  '
-            'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
-            'Modules/_weakref.o  Modules/_functoolsmodule.o  '
-            'Modules/_operator.o  Modules/_collectionsmodule.o  '
-            'Modules/itertoolsmodule.o  Modules/atexitmodule.o  '
-            'Modules/_stat.o  Modules/timemodule.o  Modules/_localemodule.o  '
+ 'MODNAMES': '_thread posix errno pwd _sre _codecs _weakref _functools '
+             '_operator _collections itertools atexit _signal _stat time '
+             '_locale _io zipimport faulthandler _tracemalloc _symtable '
+             'xxsubtype',
+ 'MODOBJS': 'Modules/_threadmodule.o  Modules/posixmodule.o  '
+            'Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  '
+            'Modules/_codecsmodule.o  Modules/_weakref.o  '
+            'Modules/_functoolsmodule.o  Modules/_operator.o  '
+            'Modules/_collectionsmodule.o  Modules/itertoolsmodule.o  '
+            'Modules/atexitmodule.o  Modules/signalmodule.o  Modules/_stat.o  '
+            'Modules/timemodule.o  Modules/_localemodule.o  '
             'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
             'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
             'Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  '
             'Modules/_tracemalloc.o Modules/hashtable.o  '
             'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
- 'MULTIARCH': '',
+ 'MULTIARCH': 'powerpc64le-linux-gnu',
+ 'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"powerpc64le-linux-gnu\\"',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DNDEBUG -fwrapv -O3 -Wall -Wstrict-prototypes',
+ 'OPT': '-DNDEBUG -fwrapv -O2 -Wall -Wstrict-prototypes',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -593,19 +624,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
  'PGEN': 'Parser/pgen',
  'PGENOBJS': '\\ \\',
- 'PGENSRCS': '\\ \\',
  'PGOBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
- 'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
- 'PGSRCS': '\\',
- 'PLATDIR': 'plat-linux',
+ 'PGO_PROF_USE_FLAG': ' ',
+ 'PLATDIR': '',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb '
-                 'test_multiprocessing_fork test_multiprocessing_forkserver '
-                 'test_multiprocessing_main_handling '
-                 'test_multiprocessing_spawn test_subprocess',
- 'PSRCS': '\\',
+ 'PROFILE_TASK': '-m test.regrtest --pgo',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
  'PY3LIBRARY': '',
@@ -615,40 +640,74 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKDIR': 'no-framework',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
- 'PYTHONPATH': ':plat-linux',
+ 'PYTHONPATH': ':',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3',
+ 'PYTHON_FOR_REGEN': 'python3.6',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILD_ENVIRON': '',
- 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -fwrapv -O3 -Wall '
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -fwrapv -O2 -Wall '
               '-Wstrict-prototypes -mcpu=power8 -mtune=power8 -mpower8-fusion '
               '-mpower8-vector -ftree-vectorize -fPIC -fstack-protector-strong '
-              '-fno-plt -O3 -pipe -mcpu=power8 -mtune=power8 -mpower8-fusion '
-              '-mpower8-vector -ftree-vectorize -fPIC -fstack-protector-strong '
-              '-fno-plt -O3 -pipe',
- 'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -fwrapv -O3 '
+              '-fno-plt -O2 '
+              '-fdebug-prefix-map=/opt/conda/conda-bld/python_1512347718438/work=/usr/local/src/conda/python-3.6.3 '
+              '-fdebug-prefix-map=/opt/anaconda1anaconda2anaconda3=/usr/local/src/conda-prefix '
+              '-pipe    '
+              '  -mcpu=power8 -mtune=power8 '
+              '-mpower8-fusion -mpower8-vector -ftree-vectorize -fPIC '
+              '-fstack-protector-strong -fno-plt -O2 '
+              '-fdebug-prefix-map=/opt/conda/conda-bld/python_1512347718438/work=/usr/local/src/conda/python-3.6.3 '
+              '-fdebug-prefix-map=/opt/anaconda1anaconda2anaconda3=/usr/local/src/conda-prefix '
+              '-pipe    '
+              ' ',
+ 'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
+                     '-Wno-unused-parameter -Wno-missing-field-initializers '
+                     '-mcpu=power8 -mtune=power8 -mpower8-fusion '
+                     '-mpower8-vector -ftree-vectorize -fPIC '
+                     '-fstack-protector-strong -fno-plt -O2 '
+                     '-fdebug-prefix-map=/opt/conda/conda-bld/python_1512347718438/work=/usr/local/src/conda/python-3.6.3 '
+                     '-fdebug-prefix-map=/opt/anaconda1anaconda2anaconda3=/usr/local/src/conda-prefix '
+                     '-pipe    '
+                     '   '
+                     '   '
+                     ' ',
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -fwrapv -O2 '
                    '-Wall -Wstrict-prototypes -mcpu=power8 -mtune=power8 '
                    '-mpower8-fusion -mpower8-vector -ftree-vectorize -fPIC '
-                   '-fstack-protector-strong -fno-plt -O3 -pipe -mcpu=power8 '
-                   '-mtune=power8 -mpower8-fusion -mpower8-vector '
-                   '-ftree-vectorize -fPIC -fstack-protector-strong -fno-plt '
-                   '-O3 -pipe -Werror=declaration-after-statement -IObjects '
-                   '-IInclude -IPython -I. '
-                   '-I/opt/conda/conda-bld/python_1512342458352/work/Include '
-                   '-D_FORTIFY_SOURCE=2 -O3 '
+                   '-fstack-protector-strong -fno-plt -O2 '
+                   '-fdebug-prefix-map=/opt/conda/conda-bld/python_1512347718438/work=/usr/local/src/conda/python-3.6.3 '
+                   '-fdebug-prefix-map=/opt/anaconda1anaconda2anaconda3=/usr/local/src/conda-prefix '
+                   '-pipe    '
+                   '  -mcpu=power8 -mtune=power8 '
+                   '-mpower8-fusion -mpower8-vector -ftree-vectorize -fPIC '
+                   '-fstack-protector-strong -fno-plt -O2 '
+                   '-fdebug-prefix-map=/opt/conda/conda-bld/python_1512347718438/work=/usr/local/src/conda/python-3.6.3 '
+                   '-fdebug-prefix-map=/opt/anaconda1anaconda2anaconda3=/usr/local/src/conda-prefix '
+                   '-pipe    '
+                   '  -std=c99 -Wextra '
+                   '-Wno-unused-result -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -mcpu=power8 -mtune=power8 '
+                   '-mpower8-fusion -mpower8-vector -ftree-vectorize -fPIC '
+                   '-fstack-protector-strong -fno-plt -O2 '
+                   '-fdebug-prefix-map=/opt/conda/conda-bld/python_1512347718438/work=/usr/local/src/conda/python-3.6.3 '
+                   '-fdebug-prefix-map=/opt/anaconda1anaconda2anaconda3=/usr/local/src/conda-prefix '
+                   '-pipe    '
+                   '   '
+                   '   '
+                   '  -IObjects -IInclude '
+                   '-IPython -I. '
+                   '-I/opt/conda/conda-bld/python_1512347718438/work/Include '
+                   '-D_FORTIFY_SOURCE=2 -O2 '
                    '-I/opt/anaconda1anaconda2anaconda3/include '
-                   '-D_FORTIFY_SOURCE=2 -O3 '
+                   '-D_FORTIFY_SOURCE=2 -O2 '
                    '-I/opt/anaconda1anaconda2anaconda3/include  '
                    '-DPy_BUILD_CORE',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/opt/conda/conda-bld/python_1512342458352/work/Include '
-                '-D_FORTIFY_SOURCE=2 -O3 '
+                '-I/opt/conda/conda-bld/python_1512347718438/work/Include '
+                '-D_FORTIFY_SOURCE=2 -O2 '
                 '-I/opt/anaconda1anaconda2anaconda3/include '
-                '-D_FORTIFY_SOURCE=2 -O3 '
+                '-D_FORTIFY_SOURCE=2 -O2 '
                 '-I/opt/anaconda1anaconda2anaconda3/include',
- 'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-O2 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
                '-Wl,-z,now '
@@ -657,7 +716,9 @@ build_time_vars = {'ABIFLAGS': 'm',
                '-Wl,-O2 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
                '-Wl,-z,now '
                '-Wl,-rpath,/opt/anaconda1anaconda2anaconda3/lib '
-               '-L/opt/anaconda1anaconda2anaconda3/lib',
+               '-L/opt/anaconda1anaconda2anaconda3/lib '
+               '   '
+               '',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 0,
  'Py_HASH_ALGORITHM': 0,
@@ -673,7 +734,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SHELL': '/bin/sh',
  'SHLIBS': '-lpthread -ldl  -lutil',
  'SHLIB_SUFFIX': '.so',
- 'SIGNAL_OBJS': '',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
@@ -693,9 +753,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-35m-powerpc64le-linux-gnu',
+ 'SOABI': 'cpython-36m-powerpc64le-linux-gnu',
  'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
- 'SRC_GDB_HOOKS': '/opt/conda/conda-bld/python_1512342458352/work/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/opt/conda/conda-bld/python_1512347718438/work/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -712,8 +772,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TESTPYTHON': './python',
  'TESTPYTHONOPTS': '',
  'TESTRUNNER': './python '
-               '/opt/conda/conda-bld/python_1512342458352/work/Tools/scripts/run_tests.py',
- 'TESTTIMEOUT': 3600,
+               '/opt/conda/conda-bld/python_1512347718438/work/Tools/scripts/run_tests.py',
+ 'TESTTIMEOUT': 1200,
  'THREADOBJ': 'Python/thread.o',
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
@@ -722,24 +782,23 @@ build_time_vars = {'ABIFLAGS': 'm',
  'UNIVERSALSDK': '',
  'USE_COMPUTED_GOTOS': 1,
  'USE_INLINE': 1,
- 'VA_LIST_IS_ARRAY': 0,
- 'VERSION': '3.5',
- 'VPATH': '/opt/conda/conda-bld/python_1512342458352/work',
+ 'VERSION': '3.6',
+ 'VPATH': '/opt/conda/conda-bld/python_1512347718438/work',
  'WANT_SIGFPE_HANDLER': 0,
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
+ 'WITH_DTRACE': 0,
  'WITH_DYLD': 0,
  'WITH_LIBINTL': 0,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
  'WITH_THREAD': 1,
- 'WITH_TSC': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/opt/conda/conda-bld/python_1512342458352/work/build-static',
- 'abs_srcdir': '/opt/conda/conda-bld/python_1512342458352/work',
+ 'abs_builddir': '/opt/conda/conda-bld/python_1512347718438/work/build-static',
+ 'abs_srcdir': '/opt/conda/conda-bld/python_1512347718438/work',
  'datarootdir': '/opt/anaconda1anaconda2anaconda3/share',
  'exec_prefix': '/opt/anaconda1anaconda2anaconda3',
  'prefix': '/opt/anaconda1anaconda2anaconda3',
- 'srcdir': '/opt/conda/conda-bld/python_1512342458352/work'}
+ 'srcdir': '/opt/conda/conda-bld/python_1512347718438/work'}
