@@ -2,14 +2,15 @@
 build_time_vars = {'ABIFLAGS': 'm',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
+ 'ANDROID_API_LEVEL': 0,
  'AR': 'x86_64-apple-darwin13.4.0-ar',
  'ARFLAGS': 'rc',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code',
  'BASECPPFLAGS': '-IObjects -IInclude -IPython',
  'BASEMODLIBS': '',
  'BINDIR': '/opt/anaconda1anaconda2anaconda3/bin',
- 'BINLIBDEST': '/opt/anaconda1anaconda2anaconda3/lib/python3.5',
- 'BLDLIBRARY': 'libpython3.5m.a',
+ 'BINLIBDEST': '/opt/anaconda1anaconda2anaconda3/lib/python3.6',
+ 'BLDLIBRARY': 'libpython3.6m.a',
  'BLDSHARED': 'x86_64-apple-darwin13.4.0-clang -bundle -undefined '
               'dynamic_lookup -isysroot /opt/MacOSX10.9.sdk -Wl,-pie '
               '-Wl,-headerpad_max_install_names '
@@ -40,7 +41,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFIGURE_CFLAGS': '-isysroot /opt/MacOSX10.9.sdk -march=core2 '
                      '-mtune=haswell -mssse3 -ftree-vectorize -fPIC -fPIE '
                      '-fstack-protector-strong -O2 -pipe ',
- 'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
+ 'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
+                            '-Wno-unused-parameter '
+                            '-Wno-missing-field-initializers',
  'CONFIGURE_CPPFLAGS': '-isysroot /opt/MacOSX10.9.sdk -D_FORTIFY_SOURCE=2 '
                        '-mmacosx-version-min=10.9 '
                        '-I/opt/anaconda1anaconda2anaconda3/include',
@@ -70,14 +73,15 @@ build_time_vars = {'ABIFLAGS': 'm',
                 "-I/opt/anaconda1anaconda2anaconda3/include' "
                 "'PKG_CONFIG_PATH=/opt/anaconda1anaconda2anaconda3/lib/pkgconfig'",
  'CONFINCLUDEDIR': '/opt/anaconda1anaconda2anaconda3/include',
- 'CONFINCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python3.5m',
- 'COREPYTHONPATH': ':plat-darwin',
- 'COVERAGE_INFO': '/opt/concourse/worker/volumes/live/79336c11-4969-4344-5768-94f7804b8ff4/volume/python_1510184839895/work/build-static/coverage.info',
- 'COVERAGE_REPORT': '/opt/concourse/worker/volumes/live/79336c11-4969-4344-5768-94f7804b8ff4/volume/python_1510184839895/work/build-static/lcov-report',
+ 'CONFINCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python3.6m',
+ 'COREPYTHONPATH': ':',
+ 'COVERAGE_INFO': '/opt/concourse/worker/volumes/live/0e6e0c36-b41a-47e3-446d-5bef219974d6/volume/python_1510184680434/work/build-static/coverage.info',
+ 'COVERAGE_REPORT': '/opt/concourse/worker/volumes/live/0e6e0c36-b41a-47e3-446d-5bef219974d6/volume/python_1510184680434/work/build-static/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
- 'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Include -isysroot '
-             '/opt/MacOSX10.9.sdk -D_FORTIFY_SOURCE=2 '
+ 'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
+             '-I/opt/concourse/worker/volumes/live/0e6e0c36-b41a-47e3-446d-5bef219974d6/volume/python_1510184680434/work/Include '
+             '-isysroot /opt/MacOSX10.9.sdk -D_FORTIFY_SOURCE=2 '
              '-mmacosx-version-min=10.9 '
              '-I/opt/anaconda1anaconda2anaconda3/include '
              '-isysroot /opt/MacOSX10.9.sdk -D_FORTIFY_SOURCE=2 '
@@ -86,11 +90,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CXX': 'x86_64-apple-darwin13.4.0-clang++',
  'DESTDIRS': '/opt/anaconda1anaconda2anaconda3 '
              '/opt/anaconda1anaconda2anaconda3/lib '
-             '/opt/anaconda1anaconda2anaconda3/lib/python3.5 '
-             '/opt/anaconda1anaconda2anaconda3/lib/python3.5/lib-dynload',
- 'DESTLIB': '/opt/anaconda1anaconda2anaconda3/lib/python3.5',
+             '/opt/anaconda1anaconda2anaconda3/lib/python3.6 '
+             '/opt/anaconda1anaconda2anaconda3/lib/python3.6/lib-dynload',
+ 'DESTLIB': '/opt/anaconda1anaconda2anaconda3/lib/python3.6',
  'DESTPATH': '',
- 'DESTSHARED': '/opt/anaconda1anaconda2anaconda3/lib/python3.5/lib-dynload',
+ 'DESTSHARED': '/opt/anaconda1anaconda2anaconda3/lib/python3.6/lib-dynload',
+ 'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
          'Makefile.pre.in Include Lib Misc Ext-dummy',
@@ -102,6 +107,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
+ 'DTRACE': '',
+ 'DTRACE_DEPS': '\\',
+ 'DTRACE_HEADERS': '',
+ 'DTRACE_OBJS': '',
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
  'ENSUREPIP': 'no',
@@ -109,7 +118,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'EXEMODE': 755,
  'EXTRAMACHDEPPATH': '',
  'EXTRATESTOPTS': '',
- 'EXT_SUFFIX': '.cpython-35m-darwin.so',
+ 'EXT_SUFFIX': '.cpython-36m-darwin.so',
  'FILEMODE': 644,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
@@ -140,13 +149,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_BROKEN_SEM_GETVALUE': 1,
  'HAVE_BROKEN_UNSETENV': 0,
  'HAVE_BUILTIN_ATOMIC': 1,
- 'HAVE_C99_BOOL': 1,
  'HAVE_CHFLAGS': 1,
  'HAVE_CHOWN': 1,
  'HAVE_CHROOT': 1,
  'HAVE_CLOCK': 1,
  'HAVE_CLOCK_GETRES': 0,
  'HAVE_CLOCK_GETTIME': 0,
+ 'HAVE_CLOCK_SETTIME': 0,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
@@ -160,6 +169,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DECL_ISFINITE': 1,
  'HAVE_DECL_ISINF': 1,
  'HAVE_DECL_ISNAN': 1,
+ 'HAVE_DECL_RTLD_DEEPBIND': 0,
+ 'HAVE_DECL_RTLD_GLOBAL': 1,
+ 'HAVE_DECL_RTLD_LAZY': 1,
+ 'HAVE_DECL_RTLD_LOCAL': 1,
+ 'HAVE_DECL_RTLD_NODELETE': 1,
+ 'HAVE_DECL_RTLD_NOLOAD': 1,
+ 'HAVE_DECL_RTLD_NOW': 1,
  'HAVE_DECL_TZNAME': 0,
  'HAVE_DEVICE_MACROS': 1,
  'HAVE_DEV_PTC': 0,
@@ -254,8 +270,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_INET_ATON': 1,
  'HAVE_INET_PTON': 1,
  'HAVE_INITGROUPS': 1,
- 'HAVE_INT32_T': 1,
- 'HAVE_INT64_T': 1,
  'HAVE_INTTYPES_H': 1,
  'HAVE_IO_H': 0,
  'HAVE_IPA_PURE_CONST_BUG': 0,
@@ -289,7 +303,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
  'HAVE_LONG_DOUBLE': 1,
- 'HAVE_LONG_LONG': 1,
  'HAVE_LSTAT': 1,
  'HAVE_LUTIMES': 1,
  'HAVE_MAKEDEV': 1,
@@ -312,7 +325,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_NICE': 1,
  'HAVE_OPENAT': 0,
  'HAVE_OPENPTY': 1,
- 'HAVE_OSX105_SDK': 1,
  'HAVE_PATHCONF': 1,
  'HAVE_PAUSE': 1,
  'HAVE_PIPE2': 0,
@@ -389,6 +401,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SIGWAIT': 1,
  'HAVE_SIGWAITINFO': 0,
  'HAVE_SNPRINTF': 1,
+ 'HAVE_SOCKADDR_ALG': 0,
  'HAVE_SOCKADDR_SA_LEN': 1,
  'HAVE_SOCKADDR_STORAGE': 1,
  'HAVE_SOCKETPAIR': 1,
@@ -407,6 +420,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_STRING_H': 1,
  'HAVE_STRLCPY': 1,
  'HAVE_STROPTS_H': 0,
+ 'HAVE_STRUCT_PASSWD_PW_GECOS': 1,
+ 'HAVE_STRUCT_PASSWD_PW_PASSWD': 1,
  'HAVE_STRUCT_STAT_ST_BIRTHTIME': 1,
  'HAVE_STRUCT_STAT_ST_BLKSIZE': 1,
  'HAVE_STRUCT_STAT_ST_BLOCKS': 1,
@@ -444,6 +459,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SYS_STATVFS_H': 1,
  'HAVE_SYS_STAT_H': 1,
  'HAVE_SYS_SYSCALL_H': 1,
+ 'HAVE_SYS_SYSMACROS_H': 0,
  'HAVE_SYS_SYS_DOMAIN_H': 1,
  'HAVE_SYS_TERMIO_H': 0,
  'HAVE_SYS_TIMES_H': 1,
@@ -469,9 +485,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_TRUNCATE': 1,
  'HAVE_TZNAME': 0,
  'HAVE_UCS4_TCL': 0,
- 'HAVE_UINT32_T': 1,
- 'HAVE_UINT64_T': 1,
- 'HAVE_UINTPTR_T': 1,
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 0,
@@ -497,16 +510,16 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HOST_GNU_TYPE': 'x86_64-apple-darwin13.4.0',
  'INCLDIRSTOMAKE': '/opt/anaconda1anaconda2anaconda3/include '
                    '/opt/anaconda1anaconda2anaconda3/include '
-                   '/opt/anaconda1anaconda2anaconda3/include/python3.5m '
-                   '/opt/anaconda1anaconda2anaconda3/include/python3.5m',
+                   '/opt/anaconda1anaconda2anaconda3/include/python3.6m '
+                   '/opt/anaconda1anaconda2anaconda3/include/python3.6m',
  'INCLUDEDIR': '/opt/anaconda1anaconda2anaconda3/include',
- 'INCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python3.5m',
+ 'INCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python3.6m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'libpython3.5m.a',
+ 'INSTSONAME': 'libpython3.6m.a',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'x86_64-apple-darwin13.4.0-clang++ -bundle -undefined '
@@ -521,7 +534,7 @@ build_time_vars = {'ABIFLAGS': 'm',
             '-L/opt/anaconda1anaconda2anaconda3/lib '
             ' -Wl,-export_dynamic',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython3.5m.a',
+ 'LDLIBRARY': 'libpython3.6m.a',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'x86_64-apple-darwin13.4.0-clang -bundle -undefined '
              'dynamic_lookup -isysroot /opt/MacOSX10.9.sdk -Wl,-pie '
@@ -533,17 +546,17 @@ build_time_vars = {'ABIFLAGS': 'm',
              '-Wl,-rpath,/opt/anaconda1anaconda2anaconda3/lib '
              '-L/opt/anaconda1anaconda2anaconda3/lib '
              ' -Wl,-export_dynamic',
- 'LDVERSION': '3.5m',
+ 'LDVERSION': '3.6m',
  'LIBC': '',
- 'LIBDEST': '/opt/anaconda1anaconda2anaconda3/lib/python3.5',
+ 'LIBDEST': '/opt/anaconda1anaconda2anaconda3/lib/python3.6',
  'LIBDIR': '/opt/anaconda1anaconda2anaconda3/lib',
  'LIBFFI_INCLUDEDIR': '/opt/anaconda1anaconda2anaconda3/include',
  'LIBM': '',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/opt/anaconda1anaconda2anaconda3/lib/pkgconfig',
- 'LIBPL': '/opt/anaconda1anaconda2anaconda3/lib/python3.5/config-3.5m',
- 'LIBRARY': 'libpython3.5m.a',
+ 'LIBPL': '/opt/anaconda1anaconda2anaconda3/lib/python3.6/config-3.6m-darwin',
+ 'LIBRARY': 'libpython3.6m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-ldl  -framework CoreFoundation',
@@ -559,35 +572,37 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LOCALMODLIBS': '',
  'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'darwin',
- 'MACHDEPPATH': ':plat-darwin',
- 'MACHDEPS': 'plat-darwin',
+ 'MACHDEPPATH': ':',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/opt/anaconda1anaconda2anaconda3/lib/python3.5',
+ 'MACHDESTLIB': '/opt/anaconda1anaconda2anaconda3/lib/python3.6',
  'MACOSX_DEPLOYMENT_TARGET': '10.9',
  'MAINCC': 'x86_64-apple-darwin13.4.0-clang',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '../Modules/makesetup',
+ 'MAKESETUP': '/opt/concourse/worker/volumes/live/0e6e0c36-b41a-47e3-446d-5bef219974d6/volume/python_1510184680434/work/Modules/makesetup',
  'MANDIR': '/opt/anaconda1anaconda2anaconda3/share/man',
- 'MKDIR_P': '../install-sh -c -d',
+ 'MKDIR_P': '/opt/concourse/worker/volumes/live/0e6e0c36-b41a-47e3-446d-5bef219974d6/volume/python_1510184680434/work/install-sh '
+            '-c -d',
  'MODLIBS': '',
- 'MODNAMES': '_thread _signal posix errno pwd _sre _codecs _weakref _functools '
-             '_operator _collections itertools atexit _stat time _locale _io '
-             'zipimport faulthandler _tracemalloc _symtable xxsubtype',
- 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  '
-            'Modules/posixmodule.o  Modules/errnomodule.o  '
-            'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
-            'Modules/_weakref.o  Modules/_functoolsmodule.o  '
-            'Modules/_operator.o  Modules/_collectionsmodule.o  '
-            'Modules/itertoolsmodule.o  Modules/atexitmodule.o  '
-            'Modules/_stat.o  Modules/timemodule.o  Modules/_localemodule.o  '
+ 'MODNAMES': '_thread posix errno pwd _sre _codecs _weakref _functools '
+             '_operator _collections itertools atexit _signal _stat time '
+             '_locale _io zipimport faulthandler _tracemalloc _symtable '
+             'xxsubtype',
+ 'MODOBJS': 'Modules/_threadmodule.o  Modules/posixmodule.o  '
+            'Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  '
+            'Modules/_codecsmodule.o  Modules/_weakref.o  '
+            'Modules/_functoolsmodule.o  Modules/_operator.o  '
+            'Modules/_collectionsmodule.o  Modules/itertoolsmodule.o  '
+            'Modules/atexitmodule.o  Modules/signalmodule.o  Modules/_stat.o  '
+            'Modules/timemodule.o  Modules/_localemodule.o  '
             'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
             'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
             'Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  '
             'Modules/_tracemalloc.o Modules/hashtable.o  '
             'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
- 'MULTIARCH': '',
+ 'MULTIARCH': 'darwin',
+ 'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"darwin\\"',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '',
  'OBJECT_OBJS': '\\',
@@ -603,19 +618,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
  'PGEN': 'Parser/pgen',
  'PGENOBJS': '\\ \\',
- 'PGENSRCS': '\\ \\',
  'PGOBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-instr-generate',
  'PGO_PROF_USE_FLAG': '-fprofile-instr-use=code.profclangd',
- 'PGSRCS': '\\',
- 'PLATDIR': 'plat-darwin',
+ 'PLATDIR': '',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb '
-                 'test_multiprocessing_fork test_multiprocessing_forkserver '
-                 'test_multiprocessing_main_handling '
-                 'test_multiprocessing_spawn test_subprocess',
- 'PSRCS': '\\',
+ 'PROFILE_TASK': '-m test.regrtest --pgo',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
  'PY3LIBRARY': '',
@@ -625,9 +634,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKDIR': 'no-framework',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
- 'PYTHONPATH': ':plat-darwin',
+ 'PYTHONPATH': ':',
  'PYTHON_FOR_BUILD': './python.exe -E',
- 'PYTHON_FOR_REGEN': 'python3',
+ 'PYTHON_FOR_REGEN': 'python3.6',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILD_ENVIRON': '',
@@ -638,38 +647,42 @@ build_time_vars = {'ABIFLAGS': 'm',
               ' -isysroot /opt/MacOSX10.9.sdk -march=core2 -mtune=haswell '
               '-mssse3 -ftree-vectorize -fPIC -fPIE -fstack-protector-strong '
               '-O2 -pipe ',
- 'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement -isysroot '
-                     '/opt/MacOSX10.9.sdk -march=core2 -mtune=haswell -mssse3 '
-                     '-ftree-vectorize -fPIC -fPIE -fstack-protector-strong '
-                     '-O2 -pipe  -fprofile-instr-use=code.profclangd '
-                     ' -Wl,-export_dynamic',
+ 'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
+                     '-Wno-unused-parameter -Wno-missing-field-initializers '
+                     '-isysroot /opt/MacOSX10.9.sdk -march=core2 '
+                     '-mtune=haswell -mssse3 -ftree-vectorize -fPIC -fPIE '
+                     '-fstack-protector-strong -O2 -pipe  '
+                     '-fprofile-instr-use=code.profclangd  '
+                     '-Wl,-export_dynamic',
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
                    '-DNDEBUG -fwrapv -O2 -Wall -Wstrict-prototypes -isysroot '
                    '/opt/MacOSX10.9.sdk -march=core2 -mtune=haswell -mssse3 '
                    '-ftree-vectorize -fPIC -fPIE -fstack-protector-strong -O2 '
                    '-pipe  -isysroot /opt/MacOSX10.9.sdk -march=core2 '
                    '-mtune=haswell -mssse3 -ftree-vectorize -fPIC -fPIE '
-                   '-fstack-protector-strong -O2 -pipe  '
-                   '-Werror=declaration-after-statement -isysroot '
+                   '-fstack-protector-strong -O2 -pipe  -std=c99 -Wextra '
+                   '-Wno-unused-result -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -isysroot '
                    '/opt/MacOSX10.9.sdk -march=core2 -mtune=haswell -mssse3 '
                    '-ftree-vectorize -fPIC -fPIE -fstack-protector-strong -O2 '
                    '-pipe  -fprofile-instr-use=code.profclangd  '
                    '-Wl,-export_dynamic -IObjects -IInclude -IPython -I. '
-                   '-I../Include -isysroot /opt/MacOSX10.9.sdk '
-                   '-D_FORTIFY_SOURCE=2 -mmacosx-version-min=10.9 '
+                   '-I/opt/concourse/worker/volumes/live/0e6e0c36-b41a-47e3-446d-5bef219974d6/volume/python_1510184680434/work/Include '
+                   '-isysroot /opt/MacOSX10.9.sdk -D_FORTIFY_SOURCE=2 '
+                   '-mmacosx-version-min=10.9 '
                    '-I/opt/anaconda1anaconda2anaconda3/include '
                    '-isysroot /opt/MacOSX10.9.sdk -D_FORTIFY_SOURCE=2 '
                    '-mmacosx-version-min=10.9 '
                    '-I/opt/anaconda1anaconda2anaconda3/include  '
                    '-DPy_BUILD_CORE',
- 'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Include -isysroot '
-                '/opt/MacOSX10.9.sdk -D_FORTIFY_SOURCE=2 '
+ 'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
+                '-I/opt/concourse/worker/volumes/live/0e6e0c36-b41a-47e3-446d-5bef219974d6/volume/python_1510184680434/work/Include '
+                '-isysroot /opt/MacOSX10.9.sdk -D_FORTIFY_SOURCE=2 '
                 '-mmacosx-version-min=10.9 '
                 '-I/opt/anaconda1anaconda2anaconda3/include '
                 '-isysroot /opt/MacOSX10.9.sdk -D_FORTIFY_SOURCE=2 '
                 '-mmacosx-version-min=10.9 '
                 '-I/opt/anaconda1anaconda2anaconda3/include',
- 'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-isysroot /opt/MacOSX10.9.sdk -Wl,-pie '
                '-Wl,-headerpad_max_install_names '
@@ -695,7 +708,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SHELL': '/bin/sh',
  'SHLIBS': '-ldl  -framework CoreFoundation',
  'SHLIB_SUFFIX': '.so',
- 'SIGNAL_OBJS': '',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
@@ -715,9 +727,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-35m-darwin',
+ 'SOABI': 'cpython-36m-darwin',
  'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
- 'SRC_GDB_HOOKS': '../Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/opt/concourse/worker/volumes/live/0e6e0c36-b41a-47e3-446d-5bef219974d6/volume/python_1510184680434/work/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -733,8 +745,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TESTPATH': '',
  'TESTPYTHON': './python.exe',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': './python.exe ../Tools/scripts/run_tests.py',
- 'TESTTIMEOUT': 3600,
+ 'TESTRUNNER': './python.exe '
+               '/opt/concourse/worker/volumes/live/0e6e0c36-b41a-47e3-446d-5bef219974d6/volume/python_1510184680434/work/Tools/scripts/run_tests.py',
+ 'TESTTIMEOUT': 1200,
  'THREADOBJ': 'Python/thread.o',
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
@@ -743,24 +756,23 @@ build_time_vars = {'ABIFLAGS': 'm',
  'UNIVERSALSDK': '',
  'USE_COMPUTED_GOTOS': 1,
  'USE_INLINE': 1,
- 'VA_LIST_IS_ARRAY': 1,
- 'VERSION': '3.5',
- 'VPATH': '..',
+ 'VERSION': '3.6',
+ 'VPATH': '/opt/concourse/worker/volumes/live/0e6e0c36-b41a-47e3-446d-5bef219974d6/volume/python_1510184680434/work',
  'WANT_SIGFPE_HANDLER': 0,
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
+ 'WITH_DTRACE': 0,
  'WITH_DYLD': 1,
  'WITH_LIBINTL': 0,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
  'WITH_THREAD': 1,
- 'WITH_TSC': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/opt/concourse/worker/volumes/live/79336c11-4969-4344-5768-94f7804b8ff4/volume/python_1510184839895/work/build-static',
- 'abs_srcdir': '/opt/concourse/worker/volumes/live/79336c11-4969-4344-5768-94f7804b8ff4/volume/python_1510184839895/work/build-static/..',
+ 'abs_builddir': '/opt/concourse/worker/volumes/live/0e6e0c36-b41a-47e3-446d-5bef219974d6/volume/python_1510184680434/work/build-static',
+ 'abs_srcdir': '/opt/concourse/worker/volumes/live/0e6e0c36-b41a-47e3-446d-5bef219974d6/volume/python_1510184680434/work',
  'datarootdir': '/opt/anaconda1anaconda2anaconda3/share',
  'exec_prefix': '/opt/anaconda1anaconda2anaconda3',
  'prefix': '/opt/anaconda1anaconda2anaconda3',
- 'srcdir': '..'}
+ 'srcdir': '/opt/concourse/worker/volumes/live/0e6e0c36-b41a-47e3-446d-5bef219974d6/volume/python_1510184680434/work'}
