@@ -1,5 +1,5 @@
-#  tests for python-3.6.6-stacklesshe025d50_0 (this is a generated file);
-print('===== testing package: python-3.6.6-stacklesshe025d50_0 =====');
+#  tests for python-3.6.8-stacklesshe025d50_1 (this is a generated file);
+print('===== testing package: python-3.6.8-stacklesshe025d50_1 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import platform
@@ -72,6 +72,7 @@ import test.support
 import unicodedata
 import zlib
 from os import urandom
+import os
 
 t = 100 * b'Foo '
 assert lzma.decompress(lzma.compress(t)) == t
@@ -96,13 +97,17 @@ if not (armv6l or armv7l or ppc64le or osx105):
     import _tkinter
     print('TK_VERSION: %s' % _tkinter.TK_VERSION)
     print('TCL_VERSION: %s' % _tkinter.TCL_VERSION)
-    TCLTK_VER = '8.6'
+    if sys.platform == 'win32':
+        TCLTK_VER = '8.6'
+    else:
+        TCLTK_VER = os.getenv("tk")
     assert _tkinter.TK_VERSION == _tkinter.TCL_VERSION == TCLTK_VER
 
 import ssl
 print('OPENSSL_VERSION:', ssl.OPENSSL_VERSION)
 if sys.platform != 'win32':
-    assert '1.0.2' in ssl.OPENSSL_VERSION
+    # this is getting the variant set at build time
+    assert os.getenv("openssl") in ssl.OPENSSL_VERSION
 #  --- run_test.py (end) ---
 
-print('===== python-3.6.6-stacklesshe025d50_0 OK =====');
+print('===== python-3.6.8-stacklesshe025d50_1 OK =====');
